//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[ChitoiHoraHandPattern](index.md)/[selfWind](self-wind.md)

# selfWind

[common]\

@EncodeDefault

open override val [selfWind](self-wind.md): [Wind](../../mahjongutils.models/-wind/index.md)? = null

自风
